==> xlr-fortify-ssc-plugin-7.6.0.zip: web/include/FortifySummaryTile/js/xlr-custom-directives.js <==
'use strict';

(() => {

    const xlrFortifyDipOfInlineWithVariablesController = function ($scope, ConfigurationInstances, Backend, Ids) {
        const vm = this;

        vm.showRequiredSign = _.isUndefined(vm.showRequiredSign) ? true : vm.showRequiredSign;
        vm.ConfigurationInstances = ConfigurationInstances;
        vm.Backend = Backend;
        vm.Ids = Ids;
        vm.onNewVariablePF = function (name, variableType, createdCallback) {
            vm.onNewVariable({
                name,
                variableType,
                createdCallback
            });
        };

        vm.metricsmap = {}
        vm.metricsmap.map={}

        vm.onChange = function(){
            if(vm.propertyValues.fortifyServer){
                const serverId = vm.Ids.toConfigurationId(vm.propertyValues.fortifyServer);
                const params = {serverId : serverId};
                vm.Backend.get('api/extension/fortify/metrics', {params: params}).then(response =>
                vm.metricsmap.map = response.data.entity );
            }
        }
        vm.onChange()

        const selectOptions = {};
        vm.selectOptions = function(p) {
            if (_.isUndefined(selectOptions[p.name])) {
                selectOptions[p.name] = (p.required ? [] : [{
                    title: "(None)",
                    id: null
                }]).concat(ConfigurationInstances.getInstancesByType(p.referencedType));
            }
            return selectOptions[p.name];
        };
        ///

        if (!ConfigurationInstances.loaded()) {
            ConfigurationInstances.load();
        }
        $scope.$on('$destroy', function () {
            ConfigurationInstances.reset();
        });
    };

    xlrFortifyDipOfInlineWithVariablesController.$inject = ['$scope', 'ConfigurationInstances', 'Backend', 'Ids'];
    angular.module('xlrelease').controller('xlrFortifyDipOfInlineWithVariablesController', xlrFortifyDipOfInlineWithVariablesController);
    angular.module('xlrelease').directive('xlrFortifyDipOfInlineWithVariables', function () {
        return {
            scope: {
                propertyDefinitions: '=',
                propertyValues: '=',
                variables: '=',
                readOnly: '=',
                enforceMode: '=',
                showRequiredSign: '=?',
                // for task input properties of type text we don't use variable selector, for output properties we do
                showVariableSelectorForText: '=',
                onChange: '&',
                onNewVariable: '&'
            },
            restrict: 'AE',
            templateUrl: 'static/@project.version@/include/FortifySummaryTile/directives/xlr-fortify-dip-of-inline-with-variables.html',
            controller: 'xlrFortifyDipOfInlineWithVariablesController',
            controllerAs: 'xlrDipCtrl',
            bindToController: true
        };
    });

    //  directive for fortify list of enum div
    angular.module('xlrelease').directive('xlrFortifyDipMapMetrics', function (xlWidgetUtils, $timeout) {

        function onModify($scope) {
            $timeout(function () {
                if (!$scope.readOnly && $scope.onChange) {
                    $scope.onChange();
                }
            });
        }

        return {
            restrict: 'A',
            scope: {
                ngModel: '=',
                metadata: '=',
                displayMode: '=?',
                readOnly: '=',
                onChange: '&',
                metricsmap: '='
            },
            templateUrl: function templateUrl(element, attrs) {
                return attrs.templateUrl || 'static/@project.version@/include/FortifySummaryTile/directives/xlr-fortify-dip-map-metrics-directive.html';
            },
            require: ['?^form', 'ngModel'],
            link: function link(scope, element, attrs, ctrls) {
                var parentForm = ctrls[0];
                scope.isRequired = scope.metadata.required;

                if (!angular.isObject(scope.ngModel)) {
                    scope.ngModel = {};
                }
                scope.$set=scope.ngModel

                scope.field = scope.metadata ? scope.metadata.field : undefined;

                if (!scope.field && !scope.readOnly) {
                    scope.$watch('$set', function (value) {
                        if (!value) return;
                        scope.ngModel=scope.$set
                        scope.updateAvailableMetrices();
                    }, true);
                }

                scope.remove = function (item) {
                    var deleted = delete scope.$set[item]
                    if (deleted) {
                        if (parentForm) {
                            parentForm.$setDirty();
                        }
                        onModify(scope);
                        scope.updateAvailableMetrices();
                    }
                };

                scope.$watch('metricsmap', function (value) {
                    scope.updateAvailableMetrices();
                }, true);

            },
            controller: function controller($scope) {
                $scope.newItem = '';

                $scope.$watch('readOnly', function () {
                    var readOnly = $scope.readOnly;
                    $scope.displayMode = readOnly ? 'visual' : 'creation';
                }, true);


                $scope.updateAvailableMetrices = function () {
                    $scope.availableMetrices = getUnconfiguredOnlyDisplayValue(getExistingMap());
                };

                $scope.addItem = function ($event) {
                    if ($event && $event.isDefaultPrevented()) return;
                    //For Firefox and IE8+
                    //!$event For add button
                    if (!$event || $event.keyCode === 13 || $event.keyCode === 0 || $event.which === 13 || $event.which === 0) {
                        if ($event) {
                            $event.preventDefault();
                        }
                        $scope.error = '';
                        if ($scope.newItem === '') return;

                        if (isSelectedValueInMetrices($scope.newItem)) {
                            $scope.$set[getAllMetricesValueToKey()[$scope.newItem]]=$scope.newItem;
                            $scope.updateAvailableMetrices();
                        }
                        $scope.newItem = '';
                        onModify($scope);
                    }
                };

                $scope.isEmpty = function () {
                    return Object.keys($scope.$set).length == 0;
                };

                function getExistingMap() {
                    return $scope.$set;
                }

                function getUnconfiguredOnlyDisplayValue(existingMap) {
                    var result=[];
                    angular.forEach(getAllMetrices(), function(value, key) {
                        if(!existingMap.hasOwnProperty(key))
                            result.push(value);
                    });
                    return result.sort();
                }

                function getAllMetrices() {
                    return $scope.metricsmap.map;
                }

                function getAllMetricesValueToKey(){
                    var result={};
                    angular.forEach(getAllMetrices(), function(value, key) {
                        result[value]=key
                    });
                    return result;
                }

                function isSelectedValueInMetrices (selectValue) {
                    var allMetricesValuesToKey = getAllMetricesValueToKey();
                    return allMetricesValuesToKey.hasOwnProperty(selectValue);
                }

                this.getScope = function () {
                    return $scope;
                };
            }
        };
    });

})();

==> xlr-fortify-ssc-plugin-7.6.1.zip: web/include/FortifySummaryTile/js/xlr-custom-directives.js <==
'use strict';

(function () {

    const xlrFortifyDipOfInlineWithVariablesController = function ($scope, ConfigurationInstances, Backend, Ids) {
        const vm = this;

        vm.showRequiredSign = _.isUndefined(vm.showRequiredSign) ? true : vm.showRequiredSign;
        vm.ConfigurationInstances = ConfigurationInstances;
        vm.Backend = Backend;
        vm.Ids = Ids;
        vm.onNewVariablePF = function (name, variableType, createdCallback) {
            vm.onNewVariable({
                name: name,
                variableType: variableType,
                createdCallback: createdCallback
            });
        };

        vm.metricsmap = {};
        vm.metricsmap.map = {};

        vm.onChange = function () {
            if (vm.propertyValues.fortifyServer) {
                const serverId = vm.Ids.toConfigurationId(vm.propertyValues.fortifyServer);
                const params = { serverId: serverId };
                vm.Backend.get('api/extension/fortify/metrics', { params: params }).then(function (response){
                    return vm.metricsmap.map = response.data.entity;
                });
            }
        };
        vm.onChange();

        const selectOptions = {};
        vm.selectOptions = function(p) {
            if (_.isUndefined(selectOptions[p.name])) {
                selectOptions[p.name] = (p.required ? [] : [{
                    title: "(None)",
                    id: null
                }]).concat(ConfigurationInstances.getInstancesByType(p.referencedType));
            }
            return selectOptions[p.name];
        };
        ///

        if (!ConfigurationInstances.loaded()) {
            ConfigurationInstances.load();
        }
        $scope.$on('$destroy', function () {
            ConfigurationInstances.reset();
        });
    };

    xlrFortifyDipOfInlineWithVariablesController.$inject = ['$scope', 'ConfigurationInstances', 'Backend', 'Ids'];
    angular.module('xlrelease').controller('xlrFortifyDipOfInlineWithVariablesController', xlrFortifyDipOfInlineWithVariablesController);
    angular.module('xlrelease').directive('xlrFortifyDipOfInlineWithVariables', function () {
        return {
            scope: {
                propertyDefinitions: '=',
                propertyValues: '=',
                variables: '=',
                readOnly: '=',
                enforceMode: '=',
                showRequiredSign: '=?',
                // for task input properties of type text we don't use variable selector, for output properties we do
                showVariableSelectorForText: '=',
                onChange: '&',
                onNewVariable: '&'
            },
            restrict: 'AE',
            templateUrl: 'static/@project.version@/include/FortifySummaryTile/directives/xlr-fortify-dip-of-inline-with-variables.html',
            controller: 'xlrFortifyDipOfInlineWithVariablesController',
            controllerAs: 'xlrDipCtrl',
            bindToController: true
        };
    });

    //  directive for fortify list of enum div
    angular.module('xlrelease').directive('xlrFortifyDipMapMetrics', function (xlWidgetUtils, $timeout) {

        function onModify($scope) {
            $timeout(function () {
                if (!$scope.readOnly && $scope.onChange) {
                    $scope.onChange();
                }
            });
        }

        return {
            restrict: 'A',
            scope: {
                ngModel: '=',
                metadata: '=',
                displayMode: '=?',
                readOnly: '=',
                onChange: '&',
                metricsmap: '='
            },
            templateUrl: function templateUrl(element, attrs) {
                return attrs.templateUrl || 'static/@project.version@/include/FortifySummaryTile/directives/xlr-fortify-dip-map-metrics-directive.html';
            },
            require: ['?^form', 'ngModel'],
            link: function link(scope, element, attrs, ctrls) {
                var parentForm = ctrls[0];
                scope.isRequired = scope.metadata.required;

                if (!angular.isObject(scope.ngModel)) {
                    scope.ngModel = {};
                }
                scope.$set = scope.ngModel;

                scope.field = scope.metadata ? scope.metadata.field : undefined;

                if (!scope.field && !scope.readOnly) {
                    scope.$watch('$set', function (value) {
                        if (!value) return;
                        scope.ngModel = scope.$set;
                        scope.updateAvailableMetrices();
                    }, true);
                }

                scope.remove = function (item) {
                    var deleted = delete scope.$set[item];
                    if (deleted) {
                        if (parentForm) {
                            parentForm.$setDirty();
                        }
                        onModify(scope);
                        scope.updateAvailableMetrices();
                    }
                };

                scope.$watch('metricsmap', function (value) {
                    scope.updateAvailableMetrices();
                }, true);

            },
            controller: function controller($scope) {
                $scope.newItem = '';

                $scope.$watch('readOnly', function () {
                    var readOnly = $scope.readOnly;
                    $scope.displayMode = readOnly ? 'visual' : 'creation';
                }, true);


                $scope.updateAvailableMetrices = function () {
                    $scope.availableMetrices = getUnconfiguredOnlyDisplayValue(getExistingMap());
                };

                $scope.addItem = function ($event) {
                    if ($event && $event.isDefaultPrevented()) return;
                    //For Firefox and IE8+
                    //!$event For add button
                    if (!$event || $event.keyCode === 13 || $event.keyCode === 0 || $event.which === 13 || $event.which === 0) {
                        if ($event) {
                            $event.preventDefault();
                        }
                        $scope.error = '';
                        if ($scope.newItem === '') return;

                        if (isSelectedValueInMetrices($scope.newItem)) {
                            $scope.$set[getAllMetricesValueToKey()[$scope.newItem]] = $scope.newItem;
                            $scope.updateAvailableMetrices();
                        }
                        $scope.newItem = '';
                        onModify($scope);
                    }
                };

                $scope.isEmpty = function () {
                    return Object.keys($scope.$set).length == 0;
                };

                function getExistingMap() {
                    return $scope.$set;
                }

                function getUnconfiguredOnlyDisplayValue(existingMap) {
                    var result = [];
                    angular.forEach(getAllMetrices(), function(value, key) {
                        if(!existingMap.hasOwnProperty(key))
                            result.push(value);
                    });
                    return result.sort();
                }

                function getAllMetrices() {
                    return $scope.metricsmap.map;
                }

                function getAllMetricesValueToKey(){
                    var result = {};
                    angular.forEach(getAllMetrices(), function(value, key) {
                        result[value] = key;
                    });
                    return result;
                }

                function isSelectedValueInMetrices (selectValue) {
                    var allMetricesValuesToKey = getAllMetricesValueToKey();
                    return allMetricesValuesToKey.hasOwnProperty(selectValue);
                }

                this.getScope = function () {
                    return $scope;
                };
            }
        };
    });
})();
